@@ -10,4 +10,9 @@ test_that("calculating phs from rho matches phis", {
     var(lr[, 1] - lr[, 2]) / var(lr[, 1] + lr[, 2]),
     phis(mail)@matrix[1, 2]
   )
+
+  expect_equal(
+    propr:::lr2phs(lr),
+    (1 - propr:::lr2rho(lr)) / (1 + propr:::lr2rho(lr))
+  )
 })
